Clojure only.

scicloj.metamorph.ml.learning-curve


learning-curveclj

(learning-curve ds pipe-fn train-sizes {:keys [k metric-fn loss-or-accuracy]})

Generates a learnining curve.

The functions splits the dataset in a fixed size test set and increasingly larger training sets. A model is trained at each step and evaluated.

Returns dataset with the learninig curve data.

  • dataset the TMD dataset to use
  • train-sizes vector of double from 0 to 1, controlling the sizes of the training data.
  • options
    • k At each step a k cross-validation is done
    • metric-fn the metric to use for evaluation the model
    • loss-or-accuracy If the metric-fn calculates :loss or :accuracy
Generates a learnining curve.

The functions splits  the dataset  in a fixed size test set
and increasingly larger training sets. A model is trained at each
step and evaluated.

Returns dataset with the learninig curve data.

- `dataset` the TMD dataset to use
- `train-sizes` vector of double from 0 to 1, controlling the sizes of the training data.
- `options`
    - `k` At each step a k cross-validation is done
    - `metric-fn` the metric to use for evaluation the model
    - `loss-or-accuracy`   If the metric-fn calculates :loss or :accuracy

sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries