Clojure only.

scicloj.metamorph.ml.pretty


prettyclj

(pretty s opts impl)

Compute pretty breaks using R function base::pretty.

Parameters:

  • s sequence of values

  • opts options for pretty,

    • :n number of breask is supported by all implementations
  • impl An implementation keyword, either

Each implementation requires dependencies to be added:

  • :ocpu : [opencpu-clj/opencpu-clj "0.3.1"]
  • :renjin : [org.renjin/renjin-script-engine "3.5-beta76"]
  • :clojisr : [scicloj/clojisr "1.1.0"]

Returns seq of the breaks, which R considers 'pretty'

Compute pretty breaks using R function base::pretty.

Parameters:
 
- `s`         sequence of values
- `opts`      options for pretty, 
     - `:n` number of breask is supported by all implementations

- `impl`       An implementation keyword, either

    - `:ocpu`    Uses an online service https://www.opencpu.org/api.html (server: cloud.opencpu.org)
    - `:renjine` Uses https://renjin.org/   
    - `:clojisr` Uses https://github.com/scicloj/clojisr, which requires a local R installation 
    - `:wadogo`  Uses plotje/wadogo (which has quite different notion of 'pretty' compared to R)

 
Each implementation requires dependencies to be added:
 
- `:ocpu` :  [opencpu-clj/opencpu-clj "0.3.1"] 
- `:renjin` : [org.renjin/renjin-script-engine "3.5-beta76"]
- `:clojisr` : [scicloj/clojisr "1.1.0"]


Returns seq of the breaks, which R considers 'pretty'
 
 
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries