(disable-cache!)Disables caching of train/predict calls.
Resets the cache configuration to a disabled state. After calling this, train and predict operations will not use any caching mechanism.
See also: enable-atom-cache!, enable-disk-cache!, enable-redis-cache!
Disables caching of train/predict calls. Resets the cache configuration to a disabled state. After calling this, train and predict operations will not use any caching mechanism. See also: `enable-atom-cache!`, `enable-disk-cache!`, `enable-redis-cache!`
(enable-atom-cache! cache-atom)Enables the caching of train/predict calls in an atom.
cache-atom: Clojure atom used for caching.
Enables the caching of train/predict calls in an atom. `cache-atom`: Clojure atom used for caching.
(enable-disk-cache! cache-dir)Enables the caching of train/predict calls in an directory on disk.
cacche-dir: Directory used for caching.
Enables the caching of train/predict calls in an directory on disk. `cacche-dir`: Directory used for caching.
(enable-redis-cache! wcar-opts)Enables the caching of train/predict calls in an redis server using carmine library
wcar-opts: Clojure atom used for caching.
'com.taoensso/carmine' needed to be added as depenency
Enables the caching of train/predict calls in an redis server using [carmine](https://github.com/taoensso/carmine) library `wcar-opts`: Clojure atom used for caching. 'com.taoensso/carmine' needed to be added as depenency
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |