scicloj.metamorph.ml.r-model-matrix


model-matrix--clojisrclj

(model-matrix--clojisr ds r-formula)
source

r-model-matrixclj

(r-model-matrix ds r-formula impl)

Compute a model matrix from a dataset and an R-style formula.

Parameters:

  • ds A tech.ml.dataset dataset representing the input data.
  • r-formula A string containing the R formula to use for model matrix construction. The formua is interpreted by R itself, so should be full compatible
  • impl An implementation keyword, either

Returns a dataset containing the constructed design matrix. Dispatches to the appropriate backend implementation.

Returns a map with

  • :model-matrix-dataset having the TMD containing the design matrix specified by r-formula
  • :attributes the (R) attributes of te model.matrix object
Compute a model matrix from a dataset and an R-style formula.

Parameters:
 
- `ds`         A tech.ml.dataset dataset representing the input data.
- `r-formula`  A string containing the R formula to use for model matrix construction. The formua is interpreted by R itself, so should be full compatible
- `impl`       An implementation keyword, either 
  - `:ocpu`    Uses an online service https://www.opencpu.org/api.html (server: cloud.opencpu.org)
  - `:renjine` Uses https://renjin.org/   
  - `:clojisr` Uses https://github.com/scicloj/clojisr, which requires a local R installation 


Returns a dataset containing the constructed design matrix.
Dispatches to the appropriate backend implementation.

 
Returns a map with 
- `:model-matrix-dataset` having the TMD containing the design matrix specified by `r-formula`
- `:attributes` the (R) attributes of te model.matrix object
 
 
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries